==> libreoffice-5.3.6.1.tar.xz: libreoffice-5.3.6.1/lotuswordpro/source/filter/benlist.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 *  The Contents of this file are made available subject to the terms of
 *  either of the following licenses
 *
 *         - GNU Lesser General Public License Version 2.1
 *         - Sun Industry Standards Source License Version 1.1
 *
 *  Sun Microsystems Inc., October, 2000
 *
 *  GNU Lesser General Public License Version 2.1
 *  =============================================
 *  Copyright 2000 by Sun Microsystems, Inc.
 *  901 San Antonio Road, Palo Alto, CA 94303, USA
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 *
 *
 *  Sun Industry Standards Source License Version 1.1
 *  =================================================
 *  The contents of this file are subject to the Sun Industry Standards
 *  Source License Version 1.1 (the "License"); You may not use this file
 *  except in compliance with the License. You may obtain a copy of the
 *  License at http://www.openoffice.org/license.html.
 *
 *  Software provided under this License is provided on an "AS IS" basis,
 *  WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING,
 *  WITHOUT LIMITATION, WARRANTIES THAT THE SOFTWARE IS FREE OF DEFECTS,
 *  MERCHANTABLE, FIT FOR A PARTICULAR PURPOSE, OR NON-INFRINGING.
 *  See the License for the specific provisions governing your rights and
 *  obligations concerning the Software.
 *
 *  The Initial Developer of the Original Code is: IBM Corporation
 *
 *  Copyright: 2008 by IBM Corporation
 *
 *  All Rights Reserved.
 *
 *  Contributor(s): _______________________________________
 *
 *
 ************************************************************************/
#include "first.hxx"
namespace OpenStormBento
{

pCBenNamedObject
FindNamedObject(pCUtList pList, const OString& rName,
  pCUtListElmt * ppPrev)
{
    CUtListElmt& rTerminating = pList->GetTerminating();
    for (pCUtListElmt pCurr = pList->GetLast(); pCurr != &rTerminating;
      pCurr = pCurr->GetPrev())
    {
        pCBenNamedObjectListElmt pCurrNamedObjectListElmt =
          static_cast<pCBenNamedObjectListElmt>(pCurr);

        sal_Int32 Comp = rName.compareTo(pCurrNamedObjectListElmt->GetNamedObject()->
          GetName());

        if (Comp == 0)
            return pCurrNamedObjectListElmt->GetNamedObject();
        else if (Comp < 0)
            continue;
        else
        {
            if (ppPrev != nullptr)
                *ppPrev = pCurrNamedObjectListElmt;
            return nullptr;
        }
    }

    if (ppPrev != nullptr)
        *ppPrev = &rTerminating;
    return nullptr;
}

// Assume list is of BenIDListElmt list elements, sorted by ID
pCBenIDListElmt
FindID(pCUtList pList, BenObjectID ObjectID, pCUtListElmt * ppPrev)
{
    CUtListElmt& rTerminating = pList->GetTerminating();
    for (pCUtListElmt pCurr = pList->GetLast(); pCurr != &rTerminating;
      pCurr = pCurr->GetPrev())
    {
        pCBenIDListElmt pCurrIDListElmt = static_cast<pCBenIDListElmt>(pCurr);

        if (ObjectID == pCurrIDListElmt->GetID())
            return pCurrIDListElmt;
        else if (ObjectID < pCurrIDListElmt->GetID())
            continue;
        else
        {
            if (ppPrev != nullptr)
                *ppPrev = pCurrIDListElmt;
            return nullptr;
        }
    }

    if (ppPrev != nullptr)
        *ppPrev = &rTerminating;
    return nullptr;
}
} //end namespace OpenStormBento

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_7.3.2.orig.tar.xz: libreoffice-7.3.2.2/lotuswordpro/source/filter/benlist.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*************************************************************************
 *
 *  The Contents of this file are made available subject to the terms of
 *  either of the following licenses
 *
 *         - GNU Lesser General Public License Version 2.1
 *         - Sun Industry Standards Source License Version 1.1
 *
 *  Sun Microsystems Inc., October, 2000
 *
 *  GNU Lesser General Public License Version 2.1
 *  =============================================
 *  Copyright 2000 by Sun Microsystems, Inc.
 *  901 San Antonio Road, Palo Alto, CA 94303, USA
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License version 2.1, as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 *  MA  02111-1307  USA
 *
 *
 *  Sun Industry Standards Source License Version 1.1
 *  =================================================
 *  The contents of this file are subject to the Sun Industry Standards
 *  Source License Version 1.1 (the "License"); You may not use this file
 *  except in compliance with the License. You may obtain a copy of the
 *  License at http://www.openoffice.org/license.html.
 *
 *  Software provided under this License is provided on an "AS IS" basis,
 *  WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING,
 *  WITHOUT LIMITATION, WARRANTIES THAT THE SOFTWARE IS FREE OF DEFECTS,
 *  MERCHANTABLE, FIT FOR A PARTICULAR PURPOSE, OR NON-INFRINGING.
 *  See the License for the specific provisions governing your rights and
 *  obligations concerning the Software.
 *
 *  The Initial Developer of the Original Code is: IBM Corporation
 *
 *  Copyright: 2008 by IBM Corporation
 *
 *  All Rights Reserved.
 *
 *  Contributor(s): _______________________________________
 *
 *
 ************************************************************************/
#include "first.hxx"
namespace OpenStormBento
{
CBenNamedObject* FindNamedObject(CUtList* pList, const OString& rName, CUtListElmt** ppPrev)
{
    CUtListElmt& rTerminating = pList->GetTerminating();
    for (CUtListElmt* pCurr = pList->GetLast(); pCurr != &rTerminating; pCurr = pCurr->GetPrev())
    {
        CBenNamedObjectListElmt* pCurrNamedObjectListElmt
            = static_cast<CBenNamedObjectListElmt*>(pCurr);

        sal_Int32 Comp = rName.compareTo(pCurrNamedObjectListElmt->GetNamedObject()->GetName());

        if (Comp == 0)
            return pCurrNamedObjectListElmt->GetNamedObject();
        else if (Comp < 0)
            continue;
        else
        {
            if (ppPrev != nullptr)
                *ppPrev = pCurrNamedObjectListElmt;
            return nullptr;
        }
    }

    if (ppPrev != nullptr)
        *ppPrev = &rTerminating;
    return nullptr;
}

// Assume list is of BenIDListElmt list elements, sorted by ID
CBenIDListElmt* FindID(CUtList* pList, BenObjectID ObjectID, CUtListElmt** ppPrev)
{
    CUtListElmt& rTerminating = pList->GetTerminating();
    for (CUtListElmt* pCurr = pList->GetLast(); pCurr != &rTerminating; pCurr = pCurr->GetPrev())
    {
        CBenIDListElmt* pCurrIDListElmt = static_cast<CBenIDListElmt*>(pCurr);

        if (ObjectID == pCurrIDListElmt->GetID())
            return pCurrIDListElmt;
        else if (ObjectID < pCurrIDListElmt->GetID())
            continue;
        else
        {
            if (ppPrev != nullptr)
                *ppPrev = pCurrIDListElmt;
            return nullptr;
        }
    }

    if (ppPrev != nullptr)
        *ppPrev = &rTerminating;
    return nullptr;
}
} //end namespace OpenStormBento

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
